@@ -64,7 +64,7 @@ class DiscreteEnv(gym.Env):
 
     #introduce some (short) length (time steps)
     self.horizon=200
-    self.are_we_done = False
+    done = False
     
     
 
@@ -81,7 +81,7 @@ class DiscreteEnv(gym.Env):
     
     #check if horizon is over, otherwise keep on going
     if self.horizon <= 0:
-        self.are_we_done = True
+        done = True
       
     data = []
     for self.state in self.dfa.itertuples(index=False):    #self.df.itertuples(index=False):
@@ -115,17 +115,16 @@ class DiscreteEnv(gym.Env):
     self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
  
     #reduce the horizon
-    self.horizon -= 1
-    
+    self.horizon -= 1    
     #set placeholder for infos
     info ={}        
      
-    return self.state, reward, self.are_we_done, theta_updated , {}
+    return self.state, reward, done, theta_updated , {}
 
 #reset state and horizon    
   def reset(self):
     self.horizon = 200
-    self.are_we_done = False
+    done = False
     
     self.dfa = pd.DataFrame(dict(
             Xsa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
